@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-certificates-extension.c,v 1.16 2004/11/16 17:06:58 chpe Exp $
+ *  $Id: ephy-certificates-extension.c,v 1.17 2005/01/05 21:07:49 jframeau Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -193,7 +193,7 @@ sync_security_status (EphyTab *tab,
 	action = gtk_ui_manager_get_action (manager, "/menubar/ViewMenu/ViewServerCertificateItem");
 	g_return_if_fail (action != NULL);
 
-	is_secure = ephy_tab_get_security_level (tab) > STATE_IS_INSECURE;
+	is_secure = ephy_tab_get_security_level (tab) > EPHY_EMBED_STATE_IS_INSECURE;
 	g_object_set (action, "sensitive", is_secure, NULL);
 }
 
