@@ -461,8 +461,8 @@ sgml_validator_validate (SgmlValidator *validator,
 		(ephy_embed_factory_new_object (EPHY_TYPE_EMBED_PERSIST));
 
 	ephy_embed_persist_set_embed (persist, embed);
-	ephy_embed_persist_set_flags (persist, EMBED_PERSIST_NO_VIEW |
-				      EMBED_PERSIST_COPY_PAGE);
+	ephy_embed_persist_set_flags (persist, EPHY_EMBED_PERSIST_NO_VIEW |
+					       EPHY_EMBED_PERSIST_COPY_PAGE);
 	ephy_embed_persist_set_dest (persist, tmp);
 
 	g_signal_connect (persist, "completed",
