@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gestures-extension.c,v 1.14 2004/09/26 16:07:58 chpe Exp $
+ *  $Id: ephy-gestures-extension.c,v 1.17 2005/01/05 21:07:49 jframeau Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -305,7 +305,7 @@ dom_mouse_down_cb (EphyEmbed *embed,
 		   EphyEmbedEvent *event,
 		   EphyGesturesExtension *extension)
 {
-        EmbedEventContext context;
+        EphyEmbedEventContext context;
 	EphyEmbedEventType type;
 	gint handled = FALSE;
 
@@ -313,7 +313,7 @@ dom_mouse_down_cb (EphyEmbed *embed,
         context = ephy_embed_event_get_context (event);
 
 	if (type == EPHY_EMBED_EVENT_MOUSE_BUTTON2 &&
-            !(context & EMBED_CONTEXT_INPUT))
+            !(context & EPHY_EMBED_CONTEXT_INPUT))
 	{
 		EphyGesture *gesture;
 		GtkWidget *toplevel;
@@ -340,12 +340,14 @@ dom_mouse_down_cb (EphyEmbed *embed,
 }
 
 static void
-tab_added_cb (GtkWidget *notebook,
-	      EphyTab *tab,
-	      EphyGesturesExtension *extension)
+impl_attach_tab (EphyExtension *extension,
+		 EphyWindow *window,
+		 EphyTab *tab)
 {
 	EphyEmbed *embed;
 
+	LOG ("Attach tab")
+
 	g_return_if_fail (EPHY_IS_TAB (tab));
 
 	embed = ephy_tab_get_embed (tab);
@@ -356,12 +358,14 @@ tab_added_cb (GtkWidget *notebook,
 }
 
 static void
-tab_removed_cb (GtkWidget *notebook,
-		EphyTab *tab,
-		EphyGesturesExtension *extension)
+impl_detach_tab (EphyExtension *extension,
+		 EphyWindow *window,
+		 EphyTab *tab)
 {
 	EphyEmbed *embed;
 
+	LOG ("Detach tab")
+
 	g_return_if_fail (EPHY_IS_TAB (tab));
 
 	embed = ephy_tab_get_embed (tab);
@@ -371,61 +375,11 @@ tab_removed_cb (GtkWidget *notebook,
 		(embed, G_CALLBACK (dom_mouse_down_cb), extension);
 }
 
-static void
-impl_attach_window (EphyExtension *ext,
-		    EphyWindow *window)
-{
-	EphyGesturesExtension *extension = EPHY_GESTURES_EXTENSION (ext);
-	GtkWidget *notebook;
-	GList *tabs, *l;
-
-	notebook = ephy_window_get_notebook (window);
-
-	tabs = ephy_window_get_tabs (window);
-
-	for (l = tabs; l != NULL; l = l->next)
-	{
-		tab_added_cb (notebook, (EphyTab *) l->data, extension);
-	}
-
-	g_list_free (tabs);
-
-	g_signal_connect (notebook, "tab_added",
-			  G_CALLBACK (tab_added_cb), extension);
-	g_signal_connect (notebook, "tab_removed",
-			  G_CALLBACK (tab_removed_cb), extension);
-}
-
-static void
-impl_detach_window (EphyExtension *ext,
-		    EphyWindow *window)
-{
-	EphyGesturesExtension *extension = EPHY_GESTURES_EXTENSION (ext);
-	GtkWidget *notebook;
-	GList *tabs, *l;
-
-	notebook = ephy_window_get_notebook (window);
-
-	g_signal_handlers_disconnect_by_func
-		(notebook, G_CALLBACK (tab_added_cb), extension);
-	g_signal_handlers_disconnect_by_func
-		(notebook, G_CALLBACK (tab_removed_cb), extension);
-
-	tabs = ephy_window_get_tabs (window);
-
-	for (l = tabs; l != NULL; l = g_list_next (l))
-	{
-		tab_removed_cb (notebook, (EphyTab *) l->data, extension);
-	}
-
-	g_list_free (tabs);
-}
-
 static void
 ephy_gestures_extension_iface_init (EphyExtensionIface *iface)
 {
-	iface->attach_window = impl_attach_window;
-	iface->detach_window = impl_detach_window;
+	iface->attach_tab = impl_attach_tab;
+	iface->detach_tab = impl_detach_tab;
 }
 
 static void
