@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: sample-mozilla.c,v 1.6 2004/12/08 15:33:53 chpe Exp $
+ *  $Id: sample-mozilla.c,v 1.7 2004/12/30 22:45:17 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-sample2-extension.h"
 #include "ephy-debug.h"
