@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: smart-bookmarks-extension.c,v 1.7 2004/12/13 18:25:17 chpe Exp $
+ *  $Id: smart-bookmarks-extension.c,v 1.9 2005/01/01 22:17:41 jframeau Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -547,7 +547,11 @@ connect_proxy_cb (GtkActionGroup *action_group,
                   GtkAction *action,
                   GtkWidget *proxy)
 {
-	if (GTK_IS_MENU_ITEM (proxy))
+	/* If NODE_ID_KEY has NULL data, we have the main menu entry, or the
+	 * context menu main entry. Allow underscores for these.
+	 */
+	if (GTK_IS_MENU_ITEM (proxy) &&
+	    g_object_get_data (G_OBJECT (action),NODE_ID_KEY) != NULL)
 	{
 		GtkLabel *label;
 	
@@ -635,7 +639,7 @@ impl_attach_window (EphyExtension *ext,
 	}
 
 	/* Action group completed */
-	gtk_ui_manager_insert_action_group (data->manager, action_group, -1),
+	gtk_ui_manager_insert_action_group (data->manager, action_group, -1);
 	g_object_unref (action_group);
 
 	/* Sync open tabs */
